@@ -7,14 +7,14 @@ use nom::{
 };
 
 use crate::{
-    repr::Extension,
     parser::{primitive::parse_f32, primitive::parse_u32},
+    repr::Extension,
 };
 
 /// Parse an [`Extension`] from `&str`.
 pub fn parse_extension(input: &str) -> IResult<&str, Extension> {
     map_res(
-        opt(alt((parse_extension_quake_2, parse_extension_hexen_2))),
+        opt(alt((parse_extension_daikatana, parse_extension_quake_2, parse_extension_hexen_2))),
         |extension| {
             if let Some(extension) = extension {
                 Ok(extension) as Result<Extension, ()>
@@ -45,3 +45,19 @@ pub fn parse_extension_quake_2(input: &str) -> IResult<&str, Extension> {
         },
     )(input)
 }
+
+/// Parse an [`Extension::Daikatana`] from `&str`.
+pub fn parse_extension_daikatana(input: &str) -> IResult<&str, Extension> {
+    map_res(
+        tuple((
+            parse_u32, space1, parse_u32, space1, parse_u32, space1, parse_u32, space1, parse_u32,
+            space1, parse_u32,
+        )),
+        |(i, _, j, _, k, _, r, _, g, _, b)| {
+            Ok(Extension::Daikatana {
+                unknown: (i, j, k),
+                color: (r, g, b),
+            }) as Result<Extension, ()>
+        },
+    )(input)
+}
